==> haskell-tasty-silver-3.3.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-silver.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-silver
version:              3.3.1
visibility:           public
id:                   tasty-silver-3.3.1-Bb6bwdBydpFJMDDXZpYXAd
key:                  tasty-silver-3.3.1-Bb6bwdBydpFJMDDXZpYXAd
license:              MIT
maintainer:           Philipp Hausmann, Andreas Abel
author:               Philipp Hausmann, Roman Cheplyaka and others
homepage:             https://github.com/phile314/tasty-silver
synopsis:             A fancy test runner, including support for golden tests.
description:
    This package provides a fancy test runner and support for «golden testing».

    A golden test is an IO action that writes its result to a file.
    To pass the test, this output file should be identical to the corresponding
    «golden» file, which contains the correct result for the test.

    The test runner allows filtering tests using regexes, and to interactively
    inspect the result of golden tests.

    This package is a heavily extended fork of tasty-golden.

category:             Testing
abi:                  20eb194160def3501e7cd50d45081c5c
exposed:              True
exposed-modules:
    Test.Tasty.Silver Test.Tasty.Silver.Advanced
    Test.Tasty.Silver.Filter Test.Tasty.Silver.Interactive
    Test.Tasty.Silver.Interactive.Run Test.Tasty.Silver.Internal

import-dirs:          /usr/lib/ghc-9.0.1/site-local/tasty-silver-3.3.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/tasty-silver-3.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/tasty-silver-3.3.1
hs-libraries:         HStasty-silver-3.3.1-Bb6bwdBydpFJMDDXZpYXAd
depends:
    ansi-terminal-0.11-Ag5cePN38Me87eTiPqxHZW
    async-2.2.3-9kX48PHnvdD9PjixjHg39U base-4.15.0.0
    bytestring-0.10.12.1 containers-0.6.4.1 deepseq-1.4.5.0
    directory-1.3.6.1 filepath-1.4.2.1 mtl-2.2.2
    optparse-applicative-0.16.1.0-3CmOuGg8I8VCCKMAPBIRLU
    process-1.6.11.0 process-extras-0.7.4-3B9UqfYzA3uBhNazZjIJ6F
    regex-tdfa-1.3.1.1-8KBKH3EsotI2v3BWqoG8PB
    silently-1.2.5.1-IkeZYC06APlDdm7dF2fIyE stm-2.5.0.0
    tagged-0.8.6.1-FL843C40q4d1DeuwYADr25
    tasty-1.4.2-5duO9gOThhmH0ll4XisXWn
    temporary-1.3-DoCk13Nh2D4AZEU9Ihg8GU text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-tasty-silver/html/tasty-silver.haddock

haddock-html:         /usr/share/doc/haskell-tasty-silver/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-silver-3.3.1.3-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-silver.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-silver
version:              3.3.1.3
visibility:           public
id:                   tasty-silver-3.3.1.3-Kw2ItYOzv3EcwQesOtli2
key:                  tasty-silver-3.3.1.3-Kw2ItYOzv3EcwQesOtli2
license:              MIT
maintainer:           Philipp Hausmann, Andreas Abel
author:               Philipp Hausmann, Roman Cheplyaka and others
homepage:             https://github.com/phile314/tasty-silver
synopsis:             A fancy test runner, including support for golden tests.
description:
    This package provides a fancy test runner and support for «golden testing».

    A golden test is an IO action that writes its result to a file.
    To pass the test, this output file should be identical to the corresponding
    «golden» file, which contains the correct result for the test.

    The test runner allows filtering tests using regexes, and to interactively
    inspect the result of golden tests.

    This package is a heavily extended fork of tasty-golden.

category:             Testing
abi:                  479b4448efa5acfc5bdc9eae2fb8efa5
exposed:              True
exposed-modules:
    Test.Tasty.Silver Test.Tasty.Silver.Advanced
    Test.Tasty.Silver.Filter Test.Tasty.Silver.Interactive
    Test.Tasty.Silver.Interactive.Run Test.Tasty.Silver.Internal

import-dirs:          /usr/lib/ghc-9.0.2/site-local/tasty-silver-3.3.1.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tasty-silver-3.3.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-silver
hs-libraries:         HStasty-silver-3.3.1.3-Kw2ItYOzv3EcwQesOtli2
depends:
    ansi-terminal-0.11.4-941itkoMzqP2HjyJtSkjHb
    async-2.2.5-CixST7EyOy65rLGgPha7A3 base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1 deepseq-1.4.5.0
    directory-1.3.6.2 filepath-1.4.2.1 mtl-2.2.2
    optparse-applicative-0.17.1.0-AxEI8mDLbJi7Q5pwqU28ta
    process-1.6.13.2 process-extras-0.7.4-K5adPO12SPP4ilna01P8jL
    regex-tdfa-1.3.2.2-I0UrgtK2N0gKpXS2O34Vp5
    silently-1.2.5.3-H31j5J4Oc25zA6fMk6qKZ stm-2.5.0.0
    tagged-0.8.8-7t9egrTqJuwIG4IxuqlUrH
    tasty-1.4.3-JF29wrJOMmrECfdI5igSTp
    temporary-1.3-CvC4UPioNJTGuU4rhEccQk text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-tasty-silver/html/tasty-silver.haddock

haddock-html:         /usr/share/doc/haskell-tasty-silver/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
